/*
 * This file is part of Technology Advancement GS, which is a GameScript 
 * for OpenTTD Copyright (C) 2012-2013  Leif Linse
 *
 * Technology Advancement GS is free software; you can redistribute it  
 * and/or modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; version 2 of the License
 *
 * Technology Advancement GS is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Technology Advancement GS; If not, see  
 * <http://www.gnu.org/licenses/> or write to the Free Software Foundation,  
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

require("version.nut");

class MainClass extends GSInfo {
	function GetAuthor()		{ return "Firrel"; }
	function GetName()			{ return "Technology Advancement"; }
	function GetDescription() 	{ return "Separates game years and technology years of engines. Allows to play in different era, have faster/slower progression or have all vehicles unlocked."; }
	function GetVersion()		{ return SELF_VERSION; }
	function GetDate()			{ return "2020-05-10"; }
	function CreateInstance()	{ return "MainClass"; }
	function GetShortName()		{ return "TEAD"; }
	function GetAPIVersion()	{ return "1.10"; }
	function GetURL()			{ return "https://www.tt-forums.net/viewtopic.php?f=65&t=87029"; }

	function GetSettings() {
		AddSetting({
			name = "technology_speed",
			description = "Speed of technology date advancement",
			easy_value = 5,
			medium_value = 5,
			hard_value = 5,
			custom_value = 5,
			flags = CONFIG_INGAME,
			min_value = 0,
			max_value = 7});
		AddLabels("technology_speed", {
			_0 = "Pause",
			_1 = "1/16",
			_2 = "1/8",
			_3 = "1/4",
			_4 = "1/2",
			_5 = "1",
			_6 = "2",
			_7 = "4" } );
	
		AddSetting({
			name = "enable_all_technology",
			description = "Enable all technology",
			easy_value = 0,
			medium_value = 0,
			hard_value = 0,
			custom_value = 0,
			flags = CONFIG_BOOLEAN });
			
		AddSetting({
			name = "technology_start_year",
			description = "Technology year at game start (0=game year)",
			easy_value = 0,
			medium_value = 0,
			hard_value = 0,
			custom_value = 0,
			flags = CONFIG_NONE,
			min_value = 0,
			max_value = 5000000,
			step_size = 10});
			
		AddSetting({
			name = "pause_after_year",
			description = "Do not retire technology after this technology year (0=always retire)",
			easy_value = 2000,
			medium_value = 2000,
			hard_value = 2000,
			custom_value = 2000,
			flags = CONFIG_NONE,
			min_value = 0,
			max_value = 5000000,
			step_size = 10});
			
		AddSetting({
			name = "rail_engine_model_life",
			description = "Number of years a rail engine will be purchasable (0=always purchasable)",
			easy_value = 25,
			medium_value = 25,
			hard_value = 25,
			custom_value = 25,
			flags = CONFIG_NONE,
			min_value = 0,
			max_value = 1000,
			step_size = 5});
			
		AddSetting({
			name = "rail_wagon_model_life",
			description = "Number of years a rail wagon will be purchasable (0=always purchasable)",
			easy_value = 0,
			medium_value = 0,
			hard_value = 0,
			custom_value = 0,
			flags = CONFIG_NONE,
			min_value = 0,
			max_value = 1000,
			step_size = 5});
			
		AddSetting({
			name = "road_vehicle_model_life",
			description = "Number of years a road vehicle will be purchasable (0=always purchasable)",
			easy_value = 45,
			medium_value = 45,
			hard_value = 45,
			custom_value = 45,
			flags = CONFIG_NONE,
			min_value = 0,
			max_value = 1000,
			step_size = 5});
			
		AddSetting({
			name = "ship_model_life",
			description = "Number of years a ship will be purchasable (0=always purchasable)",
			easy_value = 60,
			medium_value = 60,
			hard_value = 60,
			custom_value = 60,
			flags = CONFIG_NONE,
			min_value = 0,
			max_value = 1000,
			step_size = 5});
			
		AddSetting({
			name = "plane_model_life",
			description = "Number of years a plane will be purchasable (0=always purchasable)",
			easy_value = 25,
			medium_value = 25,
			hard_value = 25,
			custom_value = 25,
			flags = CONFIG_NONE,
			min_value = 0,
			max_value = 1000,
			step_size = 5});
		
		AddSetting({
			name = "log_level", 
			description = "Debug: Log level (higher = print more)", 
			easy_value = 1, 
			medium_value = 1, 
			hard_value = 1, 
			custom_value = 1, 
			flags = CONFIG_INGAME, 
			min_value = 1, 
			max_value = 3});
		AddLabels("log_level", {_1 = "1: Info", _2 = "2: Verbose", _3 = "3: Debug" } );
	}
}

RegisterGS(MainClass());
