/*
 * This file is part of Technology Advancement GS, which is a GameScript 
 * for OpenTTD Copyright (C) 2012-2013  Leif Linse
 *
 * Technology Advancement GS is free software; you can redistribute it  
 * and/or modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; version 2 of the License
 *
 * Technology Advancement GS is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Technology Advancement GS; If not, see  
 * <http://www.gnu.org/licenses/> or write to the Free Software Foundation,  
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
 
 /*
  * For tracking and advancement of technology date
  */
class TechDate
{
	date = null;
	speed = null;
	last_game_date = null;
	days_to_advance = null;

	constructor(technology_date)
	{
		this.date = technology_date;
		this.speed = GSController.GetSetting("technology_speed");
		this.last_game_date = GSDate.GetCurrentDate();
		this.days_to_advance = 0;
	}
}

function TechDate::AdvanceDate()
{
	this.speed = GSController.GetSetting("technology_speed");
	local current_game_date = GSDate.GetCurrentDate();
	local game_date_diff = current_game_date - this.last_game_date;
	this.last_game_date = current_game_date;
	
	if (this.speed == 0 || game_date_diff <= 0) {
		Log.Info("Speed is paused or game date did not advance.", Log.LVL_DEBUG);
		return false;
	}
	
	this.days_to_advance += game_date_diff;
	local advance_rate = null;
	switch (this.speed) {
		case 1:
			advance_rate = 16; // 1/16
			break;
		case 2:
			advance_rate = 8; // 1/8
			break;
		case 3:
			advance_rate = 4; // 1/4
			break;
		case 4:
			advance_rate = 2; // 1/2
			break;
		case 5:
			advance_rate = 1; // 1
			break;
		case 6:
			advance_rate = 2; // 2
			break;
		case 7:
			advance_rate = 4; // 4
			break;
	}
	
	local advanced = false;
	if (this.speed < 5) {
		while (this.days_to_advance > advance_rate) {
			this.days_to_advance -= advance_rate;
			++this.date;
			advanced = true;
		}
	} else if (this.speed >= 5) {
		if (this.days_to_advance > 0) {
			this.date += this.days_to_advance * advance_rate;
			this.days_to_advance = 0;
			advanced = true;
		}
	}
	
	if (advanced) {
		Log.Info("Technology date: " + GSDate.GetYear(this.date) + "." + GSDate.GetMonth(this.date) + "." + GSDate.GetDayOfMonth(this.date)
			   , Log.LVL_SUB_DECISIONS);
	}
		
	return advanced;
}















